PhysicalKey

Enum PhysicalKey 

pub enum PhysicalKey {
Show 108 variants KeyA, KeyB, KeyC, KeyD, KeyE, KeyF, KeyG, KeyH, KeyI, KeyJ, KeyK, KeyL, KeyM, KeyN, KeyO, KeyP, KeyQ, KeyR, KeyS, KeyT, KeyU, KeyV, KeyW, KeyX, KeyY, KeyZ, Digit0, Digit1, Digit2, Digit3, Digit4, Digit5, Digit6, Digit7, Digit8, Digit9, Minus, Equal, BracketLeft, BracketRight, Backslash, Semicolon, Quote, Backquote, Comma, Period, Slash, IntlBackslash, IntlRo, IntlYen, Escape, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, PrintScreen, ScrollLock, Pause, Insert, Home, PageUp, Delete, End, PageDown, ArrowRight, ArrowLeft, ArrowDown, ArrowUp, NumLock, NumpadDivide, NumpadMultiply, NumpadSubtract, NumpadAdd, NumpadEnter, NumpadDecimal, Numpad0, Numpad1, Numpad2, Numpad3, Numpad4, Numpad5, Numpad6, Numpad7, Numpad8, Numpad9, Backspace, Tab, Space, CapsLock, Enter, ShiftLeft, ShiftRight, ControlLeft, ControlRight, AltLeft, AltRight, SuperLeft, SuperRight, ContextMenu, Unidentified,
}
Physical key position, layout-independent (W3C KeyboardEvent.code)

Variants



KeyA



KeyB



KeyC



KeyD



KeyE



KeyF



KeyG



KeyH



KeyI



KeyJ



KeyK



KeyL



KeyM



KeyN



KeyO



KeyP



KeyQ



KeyR



KeyS



KeyT



KeyU



KeyV



KeyW



KeyX



KeyY



KeyZ



Digit0



Digit1



Digit2



Digit3



Digit4



Digit5



Digit6



Digit7



Digit8



Digit9



Minus



Equal



BracketLeft



BracketRight



Backslash



Semicolon



Quote



Backquote



Comma



Period



Slash



IntlBackslash



IntlRo



IntlYen



Escape



F1



F2



F3



F4



F5



F6



F7



F8



F9



F10



F11



F12



PrintScreen



ScrollLock



Pause



Insert



Home



PageUp



Delete



End



PageDown



ArrowRight



ArrowLeft



ArrowDown



ArrowUp



NumLock



NumpadDivide



NumpadMultiply



NumpadSubtract



NumpadAdd



NumpadEnter



NumpadDecimal



Numpad0



Numpad1



Numpad2



Numpad3



Numpad4



Numpad5



Numpad6



Numpad7



Numpad8



Numpad9



Backspace



Tab



Space



CapsLock



Enter



ShiftLeft



ShiftRight



ControlLeft



ControlRight



AltLeft



AltRight



SuperLeft



SuperRight



ContextMenu



Unidentified

Implementations

Source

impl PhysicalKey

pub fn name(self) -> &'static str

W3C code name (KeyW, Digit1, Space, …).

pub fn from_name(name: &str) -> Self

Parse a W3C code name. Unknown names map to Unidentified (never None: every physical press has a position, even when the platform cannot name it).