pub struct WindowSizeClass {
pub width: WidthClass,
pub height: HeightClass,
}Expand description
Snapshot of the current window’s size category.
The LayoutEngine updates the WindowSizeClass default local every time
the window is resized, so UI can read it via window_size_class() during
composition.
Fields
width: WidthClassheight: HeightClassImplementations
Sourceimpl WindowSizeClass
impl WindowSizeClass
Sourcepub fn is_expanded_width(&self) -> bool
pub fn is_expanded_width(&self) -> bool
true when there is enough horizontal space for multi-pane layouts.
Sourcepub fn is_at_least_medium_width(&self) -> bool
pub fn is_at_least_medium_width(&self) -> bool
true when there is enough horizontal space for a two-pane layout
(list + detail). Per M3 this is Medium or wider.