TextInputConfig

Struct TextInputConfig 

pub struct TextInputConfig {
Show 15 fields pub hint: String, pub multiline: bool, pub on_change: Option<Rc<dyn Fn(String)>>, pub on_submit: Option<Rc<dyn Fn(String)>>, pub focus_tracker: Option<Rc<Cell<bool>>>, pub value: String, pub visual_transformation: Option<Rc<dyn VisualTransformation>>, pub keyboard_type: Option<KeyboardType>, pub ime_action: Option<ImeAction>, pub enabled: bool, pub read_only: bool, pub max_lines: Option<usize>, pub min_lines: Option<usize>, pub cursor_color: Option<Color>, pub on_text_layout: Option<Rc<dyn Fn(&TextLayoutResult)>>,
}
Configuration for a text input field.

Fields

hint: Stringmultiline: boolon_change: Option<Rc<dyn Fn(String)>>on_submit: Option<Rc<dyn Fn(String)>>focus_tracker: Option<Rc<Cell<bool>>>value: Stringvisual_transformation: Option<Rc<dyn VisualTransformation>>keyboard_type: Option<KeyboardType>ime_action: Option<ImeAction>enabled: bool

When false, the text field is not editable, not focusable, and input is not selectable.

read_only: bool

When true, the text field can be focused and text can be selected/copied, but not modified.

max_lines: Option<usize>

Maximum visible lines. Only effective when multiline is true.

min_lines: Option<usize>

Minimum visible lines. Only effective when multiline is true.

cursor_color: Option<Color>

Override the cursor color. When None, uses the theme’s on_surface.

on_text_layout: Option<Rc<dyn Fn(&TextLayoutResult)>>

Callback invoked after each text layout computation, providing layout details such as line count and content size.