pub struct Composer {
pub slots: Vec<Box<dyn Any>>,
pub slot_callers: Vec<&'static Location<'static>>,
pub cursor: usize,
pub keyed_slots: FxHashMap<String, Box<dyn Any>>,
pub scope_caches: FxHashMap<String, ScopeCache>,
}Fields
slots: Vec<Box<dyn Any>>slot_callers: Vec<&'static Location<'static>>Caller identity for each slot, used to detect stale slots when the composition tree changes between frames.
cursor: usizekeyed_slots: FxHashMap<String, Box<dyn Any>>scope_caches: FxHashMap<String, ScopeCache>Per-scope cached state for the scope! macro.
Keyed by the scope key string.