pub struct TextLineInfo {
pub start: usize,
pub end: usize,
pub top: f32,
pub baseline: f32,
pub bottom: f32,
pub left: f32,
pub right: f32,
pub width: f32,
}Expand description
Layout information for a single line of text.
Fields
start: usizeByte offset of the line start in the text.
end: usizeByte offset of the line end (exclusive) in the text.
top: f32Top y position in px relative to the text field content area.
baseline: f32Baseline y position in px relative to the text field content area.
bottom: f32Bottom y position in px relative to the text field content area.
left: f32Left x position in px relative to the text field content area.
right: f32Right x position in px relative to the text field content area.
width: f32Width of this line in px.