Dp

Struct Dp 

#[repr(transparent)]
pub struct Dp(pub f32);
Density-independent pixels. Authoring APIs (Modifier, layout) take this.

Compose parity (Dp.kt): value class, Hairline/Infinity/Unspecified, isSpecified, arithmetic, coerce*, lerp.

Tuple Fields

0: f32

Implementations

Source

impl Dp

pub const ZERO: Dp

pub const HAIRLINE: Dp

Compose Dp.Hairline (0.dp: takes no space, draws 1 px).

pub const INFINITY: Dp

pub const UNSPECIFIED: Dp

Compose Dp.Unspecified (NaN sentinel).

pub const fn from_px_raw(v: f32) -> Dp

pub const fn value(self) -> f32

Raw value in dp.

pub fn is_specified(self) -> bool

false for Dp::UNSPECIFIED.

pub fn is_unspecified(self) -> bool

true for Dp::UNSPECIFIED.

pub fn take_or_else(self, block: impl FnOnce() -> Dp) -> Dp

Return self if specified, else block(). (Compose takeOrElse.)

pub fn is_finite(self) -> bool

pub fn abs(self) -> Dp

Absolute value (mirrors f32::abs).

pub fn min(self, other: Dp) -> Dp

Minimum of two Dps (mirrors f32::min).

pub fn max(self, other: Dp) -> Dp

Maximum of two Dps (mirrors f32::max).

pub fn clamp(self, min: Dp, max: Dp) -> Dp

Clamp within [min, max] (mirrors f32::clamp).

pub fn coerce_in(self, min: Dp, max: Dp) -> Dp

pub fn coerce_at_least(self, min: Dp) -> Dp

pub fn coerce_at_most(self, max: Dp) -> Dp

pub fn to_px(self) -> Px

Convert to physical pixels with the ambient Density * UiScale.

pub fn to_px_with_scale(self, scale: f32) -> Px

Convert to physical pixels with an explicit scale.

pub fn round_to_px(self) -> i32

Round to whole pixels with the ambient scale (Compose roundToPx).

pub fn to_sp(self) -> Sp

Compose FontScalingLinear.Dp.toSp: value / fontScale.

pub fn to_bits(self) -> u32

Normalized bits for hashing / scope! inputs (like f32::to_bits, with -0.0/NaN normalized).