pub struct BoxWithConstraintsScope {
pub min_width: f32,
pub max_width: f32,
pub min_height: f32,
pub max_height: f32,
}Expand description
Scope passed to BoxWithConstraints
content. All values are in dp.
Fields
min_width: f32max_width: f32min_height: f32max_height: f32Implementations
Sourceimpl BoxWithConstraintsScope
impl BoxWithConstraintsScope
Sourcepub fn has_bounded_width(&self) -> bool
pub fn has_bounded_width(&self) -> bool
true if the width is bounded by the parent (i.e. not infinite).
Sourcepub fn has_bounded_height(&self) -> bool
pub fn has_bounded_height(&self) -> bool
true if the height is bounded by the parent (i.e. not infinite).