Module runtime

Module runtime 

Structs

ComposeGuard
Composer
FocusManager
A manager for programmatic focus navigation.
FocusRequester
A handle that can programmatically request focus for a widget.
Frame
Frame - output of composition for a tick: scene + input/semantics.
HitRegion
Scheduler
SemNode
Flattened semantics node produced by layout_and_paint.

Enums

FocusDirection
Direction for focus movement.

Constants

COMPOSER

Functions

remember
Slot-based remember (sequential composition only)
remember_state
remember_state_with_key
remember_with_key
Key-based remember
spatial_focus_next
Find the next focusable element in a given spatial direction.
take_focus_request