Structs
- Compose
Guard - Composer
- Focus
Manager - A manager for programmatic focus navigation.
- Focus
Requester - A handle that can programmatically request focus for a widget.
- Frame
- Frame - output of composition for a tick: scene + input/semantics.
- HitRegion
- Scheduler
- SemNode
- Flattened semantics node produced by
layout_and_paint.
Enums
- Focus
Direction - Direction for focus movement.
Constants
Functions
- remember
- Slot-based remember (sequential composition only)
- remember_
state - remember_
state_ with_ key - remember_
with_ key - Key-based remember
- spatial_
focus_ next - Find the next focusable element in a given spatial direction.
- take_
focus_ request